@@ -148,10 +148,12 @@ class Linknx:
 		"""
 		# logger.reportDebug('Sending message to linknx: ' + message)
 		s = tcpsocket.Socket()
-		s.connect((self._host, self._port))
+		messageWithEncodingHeader = '<?xml version="1.0" encoding="ISO-8859-1"?>' + message
 		try:
-			answer = s.sendData(message)
-			# logger.reportDebug('Linknx answered ' + answer)
+			s.connect((self._host, self._port))
+			logger.reportDebug('Message sent to linknx: ' + messageWithEncodingHeader)
+			answer = s.sendData(messageWithEncodingHeader)
+			logger.reportDebug('Linknx answered ' + answer)
 			return parseString(answer[0:answer.rfind(chr(4))])
 		finally:
 			s.close()
