@@ -1,8 +1,27 @@
 #!/usr/bin/python
 
 # Copyright (C) 2012-2013 Cyrille Defranoux
+#
+# This file is part of Pyknx.
+#
+# Pyknx is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Pyknx is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Pyknx. If not, see <http://www.gnu.org/licenses/>.
+#
+# For any question, feature requests or bug reports, feel free to contact me at:
+# knx at aminate dot net
 
 import socket
+from pyknx import logger
 
 class Socket:
     def __init__(self):
